@@ -10,6 +10,7 @@ from distutils.core import run_setup
 from redbaron import RedBaron
 
 from release_new.changelog import generate_changelog
+from release_new import REVSET_QUERY
 
 
 class RepositoryNotReadForReleaseError(ValueError):
@@ -19,8 +20,7 @@ class RepositoryNotReadForReleaseError(ValueError):
 def _compute_release_tags():
     commit_desc_since_last_release = (
         subprocess.check_output(
-            "hg log -r 'ancestors(.) - ancestors(last(tag() and ancestors(.)))' "
-            "-T '{desc}\n'",
+            f"hg log -r '{REVSET_QUERY}' " "-T '{desc}\n'",
             shell=True,
         )
         .decode("utf-8")
@@ -66,6 +66,12 @@ def main():
         action="store_true",
         help="simulate a full run of release-new while not committing",
     )
+    parser.add_argument(
+        "-q",
+        "--revset-query",
+        help="the mercurial revset query to get the commit used to generate the changelog",
+        default=REVSET_QUERY,
+    )
 
     args = parser.parse_args()
 
@@ -75,18 +81,27 @@ def main():
         else:
             changelog_format = "md"
 
-        print(generate_changelog("upcoming release", format=changelog_format).strip())
+        print(
+            generate_changelog(
+                "upcoming release", format=changelog_format, revset=args.revset_query
+            ).strip()
+        )
         return
 
     try:
-        do_release(args.release_type, args.no_previous_tag_check, dry_run=args.dry_run)
+        do_release(
+            args.release_type,
+            args.no_previous_tag_check,
+            dry_run=args.dry_run,
+            revset_query=args.revset_query,
+        )
     except RepositoryNotReadForReleaseError as exception:
         # kdo Arthur
         print(f"⚠️ Error: {exception} 🤯🙉🙈💥")
         sys.exit(1)
 
 
-def do_release(release_type, no_previous_tag_check, dry_run):
+def do_release(release_type, no_previous_tag_check, dry_run, revset_query):
     if release_type == "auto":
         effective_release_type = _compute_release_tags()
     else:
@@ -152,26 +167,6 @@ def do_release(release_type, no_previous_tag_check, dry_run):
             f"{id_last_public.decode('utf-8')}"
         )
 
-    debian_directory = root / "debian"
-    has_debian_pkg = debian_directory.exists()
-
-    if not has_debian_pkg:
-        print("no debian directory found")
-
-    # verify there is a debian directory
-    #    dch must be installed
-    #    DEBEMAIL and DEBEMAIl in os.environ
-    if has_debian_pkg:
-        try:
-            subprocess.check_output(["which", "dch"])
-        except subprocess.CalledProcessError:
-            raise RepositoryNotReadForReleaseError("no dch command found")
-
-        if "DEBEMAIL" not in os.environ:
-            raise RepositoryNotReadForReleaseError("no DEBEMAIL in environment")
-        if "DEBFULLNAME" not in os.environ:
-            raise RepositoryNotReadForReleaseError("no DEBFULLNAME in environment")
-
     # get current version in the setup.py -> compare with existing tags. If it
 
     setup_result = run_setup(setup_path, stop_after="init")
@@ -277,7 +272,7 @@ def do_release(release_type, no_previous_tag_check, dry_run):
 
     changelog_content = (
         generate_changelog(
-            new_version, format=changelog_format, revset=f"{current_version}::."
+            new_version, format=changelog_format, revset=revset_query
         ).rstrip()
         + "\n\n"
         + previous_content.lstrip()
@@ -291,12 +286,6 @@ def do_release(release_type, no_previous_tag_check, dry_run):
 
     subprocess.check_call(f"hg add '{changelog_path}'", shell=True)
 
-    if has_debian_pkg:
-        subprocess.check_call(
-            f"dch -v {new_version}-1 -D unstable 'New {effective_release_type} release'",
-            shell=True,
-        )
-
     if not dry_run:
         subprocess.check_call(
             f'hg commit -m "chore(pkg): new {effective_release_type} release ({new_version})"',
